<?php

namespace Project\Task\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use Project\Task\Http\Requests\TasktypeRequest;
use Project\Task\Interfaces\TasktypeRepositoryInterface;
use Project\Task\Models\Tasktype;
use Project\Task\Forms\Tasktype as Form;

/**
 * APIController  class for tasktype.
 */
class TasktypeAPIController extends BaseController
{

    /**
     * Initialize tasktype resource controller.
     *
     * @param type TasktypeRepositoryInterface $tasktype
     *
     * @return null
     */
    public function __construct(TasktypeRepositoryInterface $tasktype)
    {
        parent::__construct();
        $this->repository = $tasktype;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Project\Task\Repositories\Criteria\TasktypeResourceCriteria::class);
    }

    /**
     * Display a list of tasktype.
     *
     * @return Response
     */
    public function index(TasktypeRequest $request)
    {
        return $this->repository
            ->setPresenter(\Project\Task\Repositories\Presenter\TasktypePresenter::class)
            ->paginate();
    }

    /**
     * Display tasktype.
     *
     * @param Request $request
     * @param Model   $tasktype
     *
     * @return Response
     */
    public function show(TasktypeRequest $request, Tasktype $tasktype)
    {
        return $tasktype->setPresenter(\Project\Task\Repositories\Presenter\TasktypeListPresenter::class);
        ;
    }

    /**
     * Create new tasktype.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(TasktypeRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('task::tasktype.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('task/tasktype/' . $tasktype->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('task/tasktype');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the tasktype.
     *
     * @param Request $request
     * @param Model   $tasktype
     *
     * @return Response
     */
    public function update(TasktypeRequest $request, Tasktype $tasktype)
    {
        try {
            $data = $request->all();

            $tasktype->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('task::tasktype.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('task/tasktype/' . $tasktype->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('task/tasktype/' . $tasktype->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the tasktype.
     *
     * @param Model   $tasktype
     *
     * @return Response
     */
    public function destroy(TasktypeRequest $request, Tasktype $tasktype)
    {
        try {
            $tasktype->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('task::tasktype.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('task/tasktype/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('task/tasktype/' . $tasktype->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
