<?php

namespace Project\Task\Policies;

use Litepie\User\Contracts\UserPolicy;
use Project\Task\Models\Tasktype;

class TasktypePolicy
{

    /**
     * Determine if the given user can view the tasktype.
     *
     * @param UserPolicy $user
     * @param Tasktype $tasktype
     *
     * @return bool
     */
    public function view(UserPolicy $user, Tasktype $tasktype)
    {
        if ($user->canDo('task.tasktype.view') && $user->isAdmin()) {
            return true;
        }

        return $tasktype->user_id == user_id() && $tasktype->user_type == user_type();
    }

    /**
     * Determine if the given user can create a tasktype.
     *
     * @param UserPolicy $user
     * @param Tasktype $tasktype
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('task.tasktype.create');
    }

    /**
     * Determine if the given user can update the given tasktype.
     *
     * @param UserPolicy $user
     * @param Tasktype $tasktype
     *
     * @return bool
     */
    public function update(UserPolicy $user, Tasktype $tasktype)
    {
        if ($user->canDo('task.tasktype.edit') && $user->isAdmin()) {
            return true;
        }

        return $tasktype->user_id == user_id() && $tasktype->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given tasktype.
     *
     * @param UserPolicy $user
     * @param Tasktype $tasktype
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Tasktype $tasktype)
    {
        return $tasktype->user_id == user_id() && $tasktype->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given tasktype.
     *
     * @param UserPolicy $user
     * @param Tasktype $tasktype
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Tasktype $tasktype)
    {
        if ($user->canDo('task.tasktype.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given tasktype.
     *
     * @param UserPolicy $user
     * @param Tasktype $tasktype
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Tasktype $tasktype)
    {
        if ($user->canDo('task.tasktype.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
