<?php

namespace Project\Task\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Illuminate\Routing\Router;
use Project\Task\Models\Task;
use Request;
use Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'Project\Task\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot()
    {
        parent::boot();

        if (Request::is('*/task/task/*')) {
            Route::bind('task', function ($task) {
                $taskrepo = $this->app->make('Project\Task\Interfaces\TaskRepositoryInterface');
                return $taskrepo->findorNew($task);
            });
        }

        if (Request::is('*/task/tasktype/*')) {
            Route::bind('tasktype', function ($tasktype) {
                $tasktyperepo = $this->app->make('Project\Task\Interfaces\TasktypeRepositoryInterface');
                return $tasktyperepo->findorNew($tasktype);
            });
        }

    }

    /**
     * Define the routes for the package.
     *
     * @return void
     */
    public function map()
    {
        $this->mapWebRoutes();
    }

    /**
     * Define the "web" routes for the package.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {   
        Route::group([
            'middleware' => 'web',
            'namespace'  => $this->namespace,
        ], function ($router) {
            require (__DIR__ . '/../../routes/web.php');
        });
    }

}
